@@ -2,23 +2,14 @@ import spacy
 from spacy.matcher import Matcher
 
 
-def create_matcher_truncated(nlp:spacy.language.Language = None, spacy_model = "en_core_web_lg"):
+def create_matcher_truncated(spacy_model = "en_core_web_lg", nlp:spacy.language.Language = None):
 
     """creates a matcher on the following vocabulary"""
     if not nlp:
-        if spacy_model == "en_core_web_lg":
-            import en_core_web_lg
-            nlp = en_core_web_lg.load(disable=["ner"])
-        elif spacy_model == "en_core_web_md":
-            import en_core_web_md
-            nlp = en_core_web_md.load(disable=["ner"])
-        elif spacy_model == "en_core_web_sm":
-            import en_core_web_sm
-            nlp = en_core_web_sm.load(disable=["ner"])
-        else:
-            nlp = spacy.load(spacy_model, disable=["ner"])
+        nlp = spacy.load(spacy_model, disable=["ner"])
     matcher = Matcher(nlp.vocab)
 
+
     # list of verbs that their adjective form 
     # is sometimes mistaken as a verb
     verbs_list = ["associate", "involve", "exhaust", "base", 
